@@ -7,7 +7,13 @@ This package contains core functionality including:
 - Common utilities and helpers
 """
 
-from .logging import ICLogger, get_logger, init_logger
+try:
+    from .logging import ICLogger, get_logger, init_logger
+except ImportError:
+    try:
+        from src.ic.core.logging import ICLogger, get_logger, init_logger
+    except ImportError:
+        from ic.core.logging import ICLogger, get_logger, init_logger
 
 __all__ = [
     'ICLogger',
